@@ -9,10 +9,10 @@ import customtkinter as ctk
 from tkinter import Menu
 from PIL import Image
 
-image_play = ctk.CTkImage(light_image=Image.open("play2.png"), size=(30, 30))
-image_stop = ctk.CTkImage(light_image=Image.open("stop2.png"), size=(30, 30))
-image_replay = ctk.CTkImage(light_image=Image.open("replay2.png"), size=(30, 30))
-image_exit = ctk.CTkImage(light_image=Image.open("x2.png"), size=(30, 30))
+image_play = ctk.CTkImage(light_image=Image.open("tinytask/src/play2.png"), size=(30, 30))
+image_stop = ctk.CTkImage(light_image=Image.open("tinytask/src/stop2.png"), size=(30, 30))
+image_replay = ctk.CTkImage(light_image=Image.open("tinytask/src/replay2.png"), size=(30, 30))
+image_exit = ctk.CTkImage(light_image=Image.open("tinytask/src/x2.png"), size=(30, 30))
 
 # Storage for recorded events and settings
 recorded_events = []
